Learn R Programming

ABCp2 (version 1.2)

fit_dist_gamma: Fit Offspring Distribution to the Gamma Distribution

Description

This function fits offspring data to a special case of the gamma distribution, in which zero values of offspring are excluded and all values are rounded to a whole number, and tests the goodness of fit using the chi-squared test.

Usage

fit_dist_gamma(dist)

Arguments

dist
a numeric vector of data values for number of offspring per dam.

Value

estimate
Shape and rate parameters estimated from the supplied distribution.
sd
Standard deviation of the shape and rate estimates.
vcov
Variance/covariance matrix of the shape and rate estimates.
loglik
the log-likelihood of the shape and rate estimates.
n
The number of observations.
statistic
The chi-squared test statistic.
parameter
Degrees of freedom for the chi-squared test.
p.value
P-value for the chi-squared test.
data_gamma
Vector of values generated from a special case of the gamma distribution.

Examples

Run this code
#Fit the Shape and Rate parameters to a distribution of offspring.
#Test the goodness of fit.

data(fungus)
fungus_fit<-fit_dist_gamma(fungus$Total_Offspring)
fungus_fit$fit_gamma
fungus_fit$chi_gamma
hist(fungus_fit$data_gamma)

Run the code above in your browser using DataLab